'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _enzyme = require('enzyme');

var _Wizard = require('./Wizard');

var _Wizard2 = _interopRequireDefault(_Wizard);

var _context = require('../context');

var _context2 = _interopRequireDefault(_context);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Steps = function Steps(_ref) {
  var children = _ref.children;
  return children;
};
Steps.defaultProps = {
  isSteps: true
};

var Step = function Step(_ref2) {
  var children = _ref2.children;
  return _react2.default.createElement(
    _context2.default.Consumer,
    null,
    function (context) {
      return typeof children === 'function' ? children(context) : children;
    }
  );
};

Step.propTypes = {
  children: _propTypes2.default.any
};

Step.defaultProps = {
  isStep: true
};

describe('Wizard', function () {
  describe('with no props', function () {
    var wrapper = void 0;
    var activeStepIndex = void 0;
    var goToNextStep = void 0;
    var goToPrevStep = void 0;
    var goToStep = void 0;
    var totalSteps = void 0;
    var onStepChanged = jest.fn();
    var onWizardFinished = jest.fn();

    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react2.default.createElement(
        _Wizard2.default,
        {
          onStepChanged: onStepChanged,
          onWizardFinished: onWizardFinished
        },
        _react2.default.createElement(
          Steps,
          null,
          _react2.default.createElement(
            Step,
            { id: 'first' },
            function (_ref3) {
              var wizardActiveStepIndex = _ref3.activeStepIndex,
                  wizardGoToNextStep = _ref3.goToNextStep,
                  wizardGoToPrevStep = _ref3.goToPrevStep,
                  wizardGoToStep = _ref3.goToStep,
                  wizardTotalSteps = _ref3.totalSteps;

              activeStepIndex = wizardActiveStepIndex;
              goToNextStep = wizardGoToNextStep;
              goToPrevStep = wizardGoToPrevStep;
              goToStep = wizardGoToStep;
              totalSteps = wizardTotalSteps;
              return null;
            }
          ),
          _react2.default.createElement(
            Step,
            { id: 'second' },
            '2'
          )
        )
      ));
    });

    var firstStep = void 0;
    var secondStep = void 0;
    var lastStep = void 0;
    var goToLastStep = void 0;

    beforeEach(function () {
      firstStep = 0;
      secondStep = 1;
      lastStep = secondStep;
      goToLastStep = function goToLastStep() {
        return goToStep(lastStep);
      };
      onStepChanged.mockReset();
      onWizardFinished.mockReset();
    });

    it('renders its steps', function () {
      expect(wrapper.contains(Steps)).toBe(true);
    });

    it('returns the number of steps', function () {
      expect(totalSteps).toBe(2);
    });

    it('starts at first step', function () {
      expect(activeStepIndex).toBe(firstStep);
    });

    it('moves to given step', function () {
      goToStep(firstStep);

      expect(activeStepIndex).toBe(firstStep);
    });

    it('moves to next step', function () {
      goToStep(firstStep);
      goToNextStep();

      expect(activeStepIndex).toBe(secondStep);
    });

    it('does not move to next step when in the last step', function () {
      goToLastStep();
      goToNextStep();

      expect(activeStepIndex).toBe(lastStep);
    });

    it('executes onFinishWizard callback when trying to navigate to last step', function () {
      goToLastStep();
      goToNextStep();

      expect(onWizardFinished).toHaveBeenCalled();
    });

    it('moves back to prev step', function () {
      goToStep(secondStep);
      goToPrevStep();

      expect(activeStepIndex).toBe(firstStep);
    });

    it('does not move to prev step when in the first step', function () {
      goToStep(firstStep);
      goToPrevStep();

      expect(activeStepIndex).toBe(firstStep);
    });

    it('executes a callback when moving through steps', function () {
      goToNextStep();

      expect(onStepChanged).toBeCalledWith({
        activeStepIndex: 1,
        step: { id: 'second' }
      });
    });
  });

  describe('passing defaultActiveStepIndex prop', function () {
    it('starts at given step', function () {
      var activeStepIndex = void 0;
      (0, _enzyme.mount)(_react2.default.createElement(
        _Wizard2.default,
        { defaultActiveStepIndex: 1 },
        _react2.default.createElement(
          Steps,
          null,
          _react2.default.createElement(
            Step,
            { id: 'first' },
            '1'
          ),
          _react2.default.createElement(
            Step,
            { id: 'second' },
            function (_ref4) {
              var wizardActiveStepIndex = _ref4.activeStepIndex;

              activeStepIndex = wizardActiveStepIndex;
              return null;
            }
          )
        )
      ));

      expect(activeStepIndex).toBe(1);
    });
  });

  describe('passing activeStepIndex prop', function () {
    it('keeps the state in the component rendering the wizard,', function () {
      var ControlledWizard = function (_React$Component) {
        _inherits(ControlledWizard, _React$Component);

        function ControlledWizard(props) {
          _classCallCheck(this, ControlledWizard);

          var _this = _possibleConstructorReturn(this, (ControlledWizard.__proto__ || Object.getPrototypeOf(ControlledWizard)).call(this, props));

          _this.state = {
            activeStepIndex: 0
          };
          return _this;
        }

        _createClass(ControlledWizard, [{
          key: 'render',
          value: function render() {
            var _this2 = this;

            return _react2.default.createElement(
              _Wizard2.default,
              {
                activeStepIndex: this.state.activeStepIndex,
                onStepChanged: function onStepChanged(_ref5) {
                  var activeStepIndex = _ref5.activeStepIndex;
                  return _this2.setState({ activeStepIndex: activeStepIndex });
                }
              },
              _react2.default.createElement(
                Steps,
                null,
                _react2.default.createElement(
                  Step,
                  { id: 'first' },
                  function (_ref6) {
                    var goToNextStep = _ref6.goToNextStep;

                    return _react2.default.createElement(
                      'button',
                      { onClick: goToNextStep },
                      'Go to next step'
                    );
                  }
                ),
                _react2.default.createElement(
                  Step,
                  { id: 'second' },
                  '2'
                )
              )
            );
          }
        }]);

        return ControlledWizard;
      }(_react2.default.Component);

      var wrapper = (0, _enzyme.mount)(_react2.default.createElement(ControlledWizard, null));
      wrapper.find('button').simulate('click');

      expect(wrapper.state().activeStepIndex).toBe(1);
    });
  });

  describe('passing history prop', function () {
    it('appends the current step id in the URL', function () {
      var push = jest.fn();
      var replace = jest.fn();
      var history = {
        listen: function listen() {},
        push: push,
        replace: replace
      };

      var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
        _Wizard2.default,
        { history: history, baseUrl: '/steps' },
        _react2.default.createElement(
          Steps,
          null,
          _react2.default.createElement(
            Step,
            { id: 'first' },
            function (_ref7) {
              var goToNextStep = _ref7.goToNextStep;

              return _react2.default.createElement(
                'button',
                { onClick: goToNextStep },
                'Go to next step'
              );
            }
          ),
          _react2.default.createElement(
            Step,
            { id: 'second' },
            '2'
          )
        )
      ));

      expect(replace).toHaveBeenCalledWith('/steps/first');

      wrapper.find('button').simulate('click');

      expect(push).toHaveBeenCalledWith('/steps/second');
    });

    describe('with conditional step', function () {
      it('ignores the step', function () {
        var push = jest.fn();
        var replace = jest.fn();
        var history = {
          listen: function listen() {},
          push: push,
          replace: replace
        };

        (0, _enzyme.mount)(_react2.default.createElement(
          _Wizard2.default,
          { history: history, baseUrl: '/steps' },
          _react2.default.createElement(
            Steps,
            null,
            false && _react2.default.createElement(
              Step,
              { id: 'first' },
              '1'
            ),
            _react2.default.createElement(
              Step,
              { id: 'second' },
              '2'
            )
          )
        ));

        expect(replace).not.toHaveBeenCalledWith('/steps/first');
        expect(replace).toHaveBeenCalledWith('/steps/second');
      });
    });

    describe('with new props', function () {
      var component = (0, _enzyme.shallow)(_react2.default.createElement(
        _Wizard2.default,
        null,
        _react2.default.createElement(Steps, null)
      ));

      it('sets new steps', function () {
        var spy = jest.spyOn(_Wizard2.default.prototype, 'steps', 'get');
        component.setProps({ children: _react2.default.createElement(Steps, null) });

        expect(spy).toHaveBeenCalledTimes(1);
        spy.mockRestore();
      });

      it('does not set new steps when children are not updated', function () {
        var spy = jest.spyOn(_Wizard2.default.prototype, 'steps', 'get');
        component.setProps({ aProp: 'prop' });

        expect(spy).not.toHaveBeenCalled();
        spy.mockRestore();
      });
    });
  });
});